@@ -414,7 +414,7 @@ class NamedMatrix(object):
         return mat
     
     @staticmethod
-    def load_from_file(file, sourcecode = None, has_header=True, delimiter=',', matrix=False):
+    def load_from_file(file, sourcecode = None, has_header=True, delimiter=',', matrix=False, merge= lambda x: x[0]):
         """Load a matrix from a file.  Any missing values are assumed to 
            be 0.  The row and column names are sorted and the shape of
            the matrix is determined by the number of rows (1st column)
@@ -461,7 +461,9 @@ class NamedMatrix(object):
             if sourcecode is None or source is None or source in sourcecode:
                 if not values.has_key(name1):
                     values[name1] = dict()
-                values[name1][name2] = float(val)
+                if not values.has_key(name2):
+                    values[name1][name2] = list()
+                values[name1][name2].append( float(val) )
                 rownames[name1] = True
                 colnames[name2] = True
         
@@ -472,7 +474,7 @@ class NamedMatrix(object):
                 value = 0
                 if values.has_key(name1):
                     if values[name1].has_key(name2):
-                        value = values[name1][name2]
+                        value = float( merge( values[name1][name2] ) )
                 row.append(value)
             rows.append(row)
             
